@@ -1,12 +1,12 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
+__version__ = '0.4'
+
 from os.path import dirname, join
-from _zipcodetw import Directory, __version__
+from .util import Directory
 
 _project_root = dirname(__file__)
 
-_dir = Directory()
-_dir.load_chp_csv(open(join(_project_root, '201311.csv')))
-
+_dir = Directory(join(_project_root, '201311.db'))
 find = _dir.find
